@@ -1,7 +1,10 @@
 import json
 from collections import OrderedDict
+from enum import Enum
 from functools import wraps, partial
+from typing import Tuple, Union
 
+from .validator import Validator
 from ..config import AppConfig
 from ..http import HttpRequest, HttpServerError
 from ..http import HttpResponse, HttpBadRequest, JsonResponse
@@ -11,7 +14,7 @@ from ..util import Logger
 from ..util.func_util import ArgumentSpecification, get_func_info
 
 
-def route(module=None, name=None, extname=None, **kwargs):
+def route(module=None, name=None, extname=None, validators: Union[Tuple[Validator], Validator] = None, **kwargs):
     """
     用于控制路由的访问权限，路由均需要添加此装饰器，若未添加，则不可访问
     用法：
@@ -21,8 +24,14 @@ def route(module=None, name=None, extname=None, **kwargs):
     :param module: str 路由所属模块，一般在查询权限时会用到
     :param name: str 路由名称，一般在查询权限时会用到
     :param extname: 给路径指定一个扩展名，不能包含 . 符号
+    :param validators: 指定参数应用的校验规则，每个需要校验的参数为元组的一个项
     """
 
+    # 支持错误的元组写法: (aaa)
+    # 正确写法应该为: (aaa,)
+    if not isinstance(validators, tuple) and validators is not None:
+        validators = (validators,)
+
     def invoke_route(handler):
         @wraps(handler)
         def caller(*args):
@@ -57,14 +66,38 @@ def route(module=None, name=None, extname=None, **kwargs):
                 kwargs=kwargs,
             )
 
-            return _invoke_with_route(request, meta, config)
+            return _invoke_with_route(request, meta, config, validators)
 
         return caller
 
     return invoke_route
 
 
-def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig):
+def validate_args(func, validators: Tuple[Validator], args: dict):
+    if not validators:
+        return None
+
+    if not args:
+        return None
+
+    param_name = None
+    result = None
+    for validator in validators:
+        param_name = validator._param_name
+        result = validator.validate(args)
+        if result is None:
+            continue
+        break
+    if result is None:
+        return result
+
+    return 'Incorrect value of parameter "%s": %s' % (
+        param_name,
+        result
+    )
+
+
+def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig, validators: tuple):
     handler_args = meta.handler_args
     func = meta.handler
 
@@ -108,6 +141,11 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig)
     if result is not None:
         return handle_response(wrap_response(result))
 
+    # 执行校验
+    result = validate_args(func, validators, actual_args)
+    if result is not None:
+        return HttpBadRequest(result, content_type='text/plain')
+
     # 调用路由函数
     arg_len = len(handler_args)
 
@@ -188,6 +226,19 @@ def _get_value(data: dict, name: str, arg_spec: ArgumentSpecification, backup1,
     return None, None
 
 
+def _get_enum_value(arg_spec, arg_value):
+    # 此处的判断，始终忽略大小写
+    tv = str(arg_value).lower()
+    for enum_item in arg_spec.annotation:
+        # 先判断值
+        # 再判断名称
+        if str(enum_item.value).lower() == tv or str(enum_item.name).lower() == tv:
+            # 命中了此枚举项
+            return enum_item
+    # 没有命中
+    return None
+
+
 def _get_actual_args(request: HttpRequest, func, args: OrderedDict, config: AppConfig) -> dict or HttpResponse:
     method = request.method.lower()
     actual_args = {}
@@ -301,11 +352,25 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, config: AppC
                 used_args.append(arg_name)
                 continue
 
-            msg = 'Cannot parse value "%s" into type "%s: %s". (expected: true/false)' % (
+            msg = 'Cannot parse value "%s" as type "%s for parameter %s". (expected: true/false)' % (
                 (arg_value, arg_spec.annotation_name, arg_name))
             Logger.get(config.app_id).warning(msg)
             return HttpBadRequest(msg)
 
+        # 当声明的参数类型是枚举类型时，遍历枚举项，同时将枚举名称与值进行处理
+        if issubclass(arg_spec.annotation, Enum):
+            result = _get_enum_value(arg_spec, arg_value)
+            if result is None:
+                msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
+                    arg_value, arg_spec.annotation_name, arg_name
+                )
+                Logger.get(config.app_id).warning(msg)
+                return HttpBadRequest(msg)
+
+            actual_args[arg_name] = result
+            used_args.append(arg_name)
+            continue
+
         # 转换失败时，会抛出异常
         # noinspection PyBroadException
         try:
@@ -316,7 +381,7 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, config: AppC
                     arg_value = json.loads(arg_value)
                 except Exception:
                     # 此处的异常直接忽略即可
-                    msg = 'Cannot parse value "%s" into type "%s": %s.' % (
+                    msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
                         arg_value, arg_spec.annotation_name, arg_name
                     )
                     Logger.get(config.app_id).warning(msg)
@@ -332,7 +397,7 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, config: AppC
             actual_args[arg_name] = arg_spec.annotation(arg_value)
             used_args.append(arg_name)
         except Exception:
-            msg = 'Cannot parse value "%s" into type "%s": %s.' % (
+            msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
                 arg_value, arg_spec.annotation_name, arg_name
             )
             Logger.get(config.app_id).warning(msg)
